%define _prefix  /scisoft
%define _docdir %{_prefix}/doc
# Skycat's build system does not properly adhere to the paths it gets given by
# the configure script. Thus, need to override the library destination for the
# program to actually to work.
%define _libdir %{_prefix}/lib
# Skycat hardcodes the build path into some debug symbols in its libraries.
# These are not easy to get rid of. Thus, we disable the check-buildroot script
# and only run check-rpaths.
%define __arch_install_post /usr/lib/rpm/check-rpaths

Name:           scisoft-skycat
Version:        3.1.3
Release:        1%{?dist}
Summary:        FITS Image Display and Catalog Search Tool for Astronomy
Distribution:   Scisoft
License:        GPLv2+
Group:          Applications/Scientific
URL:            http://archive.eso.org/cms/tools-documentation/skycat
Source0:        ftp://ftp.eso.org/usg/skycat/skycat-%{version}.tar.gz
Source1:        http://archive.eso.org/cms/tools-documentation/skycat-download/tcltk-8.4.1-1.tar.gz
Patch0:         blt_library_Makefile_in.patch
Patch1:         blt_Makefile_in.patch

BuildRequires:  gcc-c++
BuildRequires:  libX11-devel
BuildRequires:  libXext-devel

%description
SkyCat is a tool that combines visualization of images and access to
catalogs and archive data for astronomy.
Note: There is also a Java version of Skycat called JSkycat available
as part of the JSky package.

Authors:
--------
    Allan Brighton (abrighto@eso.org)
    Thomas Herlin (therlin@eso.org)
    Miguel Albrecht (malbrech@eso.org)
    Daniel Durand (durand@dao.nrc.ca)
    Peter Biereichel (pbiereic@eso.org)

%prep
%setup -q -n skycat-%{version}
%setup -q -T -b  1 -n tcltk-8.4.1
%patch0 -p0
%patch1 -p0

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"

# Build the core Tcl/Tk libraries and interpreter first. We will have to install
# them temporarily so that Skycat can be built against this internal Tcl/Tk.
# The PATH is setup so that iwidgets can find the tclsh binary.
export PATH="%{buildroot}%{_libexecdir}/skycat-%{version}/bin:$PATH"

cd %{_builddir}/tcltk-8.4.1/tcl[0-9]*/unix
./configure --build=%{_build} --host=%{_host} \
            --prefix=%{_libexecdir}/skycat-%{version} --enable-shared
%make_build
%make_install

cd %{_builddir}/tcltk-8.4.1/tk[0-9]*/unix
# NOTE: the --x-libraries='' option is needed to produce correct RPATHS. The Tk
# build system will end up using -lX11 anyway. But without --x-libraries='' we
# end up with a string 'NONE' in the RPATH.
./configure --build=%{_build} --host=%{_host} \
            --prefix=%{_libexecdir}/skycat-%{version} --enable-shared --x-libraries=''
%make_build
%make_install

cd %{_builddir}/tcltk-8.4.1/tclx[0-9]*
./configure --build=%{_build} --host=%{_host} \
            --prefix=%{_libexecdir}/skycat-%{version} --enable-shared
%make_build
%make_install

cd %{_builddir}/tcltk-8.4.1/itcl[0-9]*
./configure --build=%{_build} --host=%{_host} \
            --prefix=%{_libexecdir}/skycat-%{version} --enable-shared
%make_build
%make_install

cd %{_builddir}/tcltk-8.4.1/iwidgets[0-9]*
./configure --build=%{_build} --host=%{_host} \
            --prefix=%{_libexecdir}/skycat-%{version} --enable-shared
%make_build
make install INSTALL_ROOT=%{buildroot}

cd %{_builddir}/tcltk-8.4.1/tkimg[0-9]*
# Note: the invokation of configure in the libjpeg directory is to work around
# a problem in the build system, where jconfig.h is not properly generated.
cd libjpeg
./configure
cd ..
./configure --build=%{_build} --host=%{_host} \
            --prefix=%{_libexecdir}/skycat-%{version} --enable-shared
%make_build
make install INSTALL_ROOT=%{buildroot}

cd %{_builddir}/tcltk-8.4.1/blt[0-9]*
# Have to patch the Makefile templates to have correct RPATHs.
sed -i -e 's|@LD_RUN_PATH@|-Wl,-rpath,%{_libexecdir}/skycat-%{version}/lib|' src/Makefile.in
sed -i -e 's|@LD_RUN_PATH@|-Wl,-rpath,%{_libexecdir}/skycat-%{version}/lib|' src/shared/Makefile.in
./configure --build=%{_build} --host=%{_host} \
            --prefix=%{_libexecdir}/skycat-%{version} \
            --x-libraries=/usr/%{_lib} --x-includes=/usr/include \
            --with-tcl=%{buildroot}%{_libexecdir}/skycat-%{version}/lib \
            --with-tk=%{buildroot}%{_libexecdir}/skycat-%{version}/lib \
            --enable-shared
# Cannot perform parallel build due to race conditions.
make
make install INSTALL_ROOT=%{buildroot}

# NOTE: The -Wno-narrowing and -fpermissive flags is needed for newer gcc
# compilers. This should actually be cleaned up in the upstream code.
export CFLAGS="%{optflags} -fno-strict-aliasing -Wno-narrowing -fpermissive"
cd %{_builddir}/skycat-%{version}
./configure --build=%{_build} --host=%{_host} \
            --prefix=%{_libexecdir}/skycat-%{version} \
            --exec-prefix=%{_libexecdir}/skycat-%{version} \
            --bindir=%{_libexecdir}/skycat-%{version}/bin \
            --libdir=%{_libexecdir}/skycat-%{version}/lib \
            --includedir=%{_libexecdir}/skycat-%{version}/include \
            --mandir=%{_mandir} \
            --with-tcl=%{buildroot}%{_libexecdir}/skycat-%{version}/lib \
            --with-tk=%{buildroot}%{_libexecdir}/skycat-%{version}/lib
# Need to setup LD_LIBRARY_PATH so that the following invocation succeeds:
#   tclsh8.4 mkIndex.tcl
export LD_LIBRARY_PATH=%{buildroot}%{_libexecdir}/skycat-%{version}/lib
make

%install
install -m 755 -d %{buildroot}%{_datadir}
install -m 755 -d %{buildroot}%{_docdir}
install -m 755 -d %{buildroot}%{_licensedir}

cd %{_builddir}/tcltk-8.4.1/tcl[0-9]*/unix
%make_install
# Remove traces of the builddir from the Tcl configure script.
sed -i -e "s|$PWD|%{_libexecdir}/skycat-%{version}/lib|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/tclConfig.sh
sed -i -e "s|%{_builddir}|/usr/src/debug|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/tclConfig.sh

cd %{_builddir}/tcltk-8.4.1/tk[0-9]*/unix
%make_install
# Remove traces of the builddir from the Tk configure script.
sed -i -e "s|$PWD|%{_libexecdir}/skycat-%{version}/lib|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/tkConfig.sh
sed -i -e "s|%{_builddir}|/usr/src/debug|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/tkConfig.sh

cd %{_builddir}/tcltk-8.4.1/tclx[0-9]*
%make_install

cd %{_builddir}/tcltk-8.4.1/itcl[0-9]*
%make_install
# Remove traces of the builddir from the itcl configure script.
sed -i -e "/_BUILD_/ s|$PWD|%{_libexecdir}/skycat-%{version}/lib|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/itclConfig.sh
sed -i -e "s|%{_builddir}|/usr/src/debug|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/itclConfig.sh

cd %{_builddir}/tcltk-8.4.1/iwidgets[0-9]*
make install INSTALL_ROOT=%{buildroot}

cd %{_builddir}/tcltk-8.4.1/tkimg[0-9]*
make install INSTALL_ROOT=%{buildroot}
# Remove traces of the builddir from the itcl configure scripts.
TKIMGVER=`basename $PWD | sed 's|[[:alpha:]]*||'`
sed -i -e "s|$PWD/libjpeg/tcl|%{_libexecdir}/skycat-%{version}/lib/Img$TKIMGVER|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/jpegtclConfig.sh
sed -i -e "s|$PWD/libpng/tcl|%{_libexecdir}/skycat-%{version}/lib/Img$TKIMGVER|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/pngtclConfig.sh
sed -i -e "s|$PWD/libtiff/tcl|%{_libexecdir}/skycat-%{version}/lib/Img$TKIMGVER|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/tifftclConfig.sh
sed -i -e "s|$PWD/base|%{_libexecdir}/skycat-%{version}/lib/Img$TKIMGVER|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/tkimgConfig.sh
sed -i -e "s|$PWD/libz/tcl|%{_libexecdir}/skycat-%{version}/lib/Img$TKIMGVER|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/zlibtclConfig.sh

cd %{_builddir}/tcltk-8.4.1/blt[0-9]*
make install INSTALL_ROOT=%{buildroot}

# Need to setup LD_LIBRARY_PATH so that the following invocation succeeds:
#   tclsh8.4 mkIndex.tcl
export LD_LIBRARY_PATH=%{buildroot}%{_libexecdir}/skycat-%{version}/lib
cd %{_builddir}/skycat-%{version}
%make_install
# Remove traces of the buildroot and builddir from the Skycat configure and
# launch scripts.
sed -i -e "/_BUILD_/ s|$PWD/tclutil|%{_libexecdir}/skycat-%{version}/lib|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/tclutilConfig.sh
sed -i -e "s|%{_builddir}|/usr/src/debug|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/tclutilConfig.sh
sed -i -e "/_BUILD_/ s|$PWD/astrotcl|%{_libexecdir}/skycat-%{version}/lib|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/astrotclConfig.sh
sed -i -e "s|%{_builddir}|/usr/src/debug|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/astrotclConfig.sh
sed -i -e "/_BUILD_/ s|$PWD/rtd|%{_libexecdir}/skycat-%{version}/lib|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/rtdConfig.sh
sed -i -e "s|%{_builddir}|/usr/src/debug|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/rtdConfig.sh
sed -i -e "/_BUILD_/ s|$PWD/cat|%{_libexecdir}/skycat-%{version}/lib|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/catConfig.sh
sed -i -e "s|%{_builddir}|/usr/src/debug|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/catConfig.sh
sed -i -e "/_BUILD_/ s|$PWD/skycat|%{_libexecdir}/skycat-%{version}/lib|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/skycatConfig.sh
sed -i -e "s|%{_builddir}|/usr/src/debug|" %{buildroot}%{_libexecdir}/skycat-%{version}/lib/skycatConfig.sh
sed -i -e "s|%{buildroot}||" %{buildroot}%{_libexecdir}/skycat-%{version}/bin/rtd
sed -i -e "s|%{buildroot}||" %{buildroot}%{_libexecdir}/skycat-%{version}/bin/skycat

install -m 755 -d %{buildroot}%{_bindir}
ln -s %{_libexecdir}/skycat-%{version}/bin/skycat %{buildroot}%{_bindir}/skycat
ln -s %{_libexecdir}/skycat-%{version}/bin/rtd %{buildroot}%{_bindir}/rtd
ln -s %{_libexecdir}/skycat-%{version}/bin/tRtd %{buildroot}%{_bindir}/tRtd
ln -s %{_libexecdir}/skycat-%{version}/bin/rtdClient %{buildroot}%{_bindir}/rtdClient
ln -s %{_libexecdir}/skycat-%{version}/bin/rtdServer %{buildroot}%{_bindir}/rtdServer
ln -s %{_libexecdir}/skycat-%{version}/bin/rtdCubeDisplay %{buildroot}%{_bindir}/rtdCubeDisplay

# Remove demo directories in iwidgets4.0.1 and blt2.4 that cause numerous shebang related errors 
rm -r  %{buildroot}%{_libexecdir}/skycat-%{version}/lib/iwidgets4.0.1/demos
rm -r  %{buildroot}%{_libexecdir}/skycat-%{version}/lib/blt2.4/demos

# Prevent failure due to RPATH usage in Tcl/Tk.
export QA_RPATHS=$[ 0x0002 ]

%files
%dir %{_datadir}
%dir %{_docdir}
%dir %{_licensedir}
%defattr(-,root,root,-)
%doc ../skycat-%{version}/CHANGES ../skycat-%{version}/README
%license ../skycat-%{version}/COPYING
%{_prefix}

%changelog
* Mon Jul 9 2018 Artur Szostak <aszostak@partner.eso.org> 3.1.4
- Updating for new Skycat patch version.

* Thu Mar 1 2018 Artur Szostak <aszostak@partner.eso.org> 3.1.3
- Changing back to using internal Tcl/Tk 8.4, since Skycat is unstable on newer
  Tcl/Tk versions.

* Tue Feb 27 2018 Artur Szostak <aszostak@partner.eso.org> 3.1.2
- Integrated into automatic build system for Scisoft.
- Updating to use standard RPM packaging macros.
- Changing dependencies to use the system Tcl/Tk.

* Tue Oct 18 2016 Artur Szostak <aszostak@partner.eso.org> 3.1.2-2
- Adding missing build dependencies.
- Suppressing gcc warnings that cause compilation failures.

* Tue Oct 08 2013 Carlos Guirao <cguirao@eso.org>
- Replacing TCLTK_ROOT with SCISOFT_ROOT

* Thu May 19 2011 Carlos Guirao <cguirao@eso.org>
- Fix a bug in rtd/rtdev/rtd_server.C detected on Fedora 14 with gcc 4.5.1

* Fri Jul 16 2010 Carlos Guirao <cguirao@eso.org>
- Using defaults /usr/local if $TCLTK_ROOT not defined

* Mon Jan 30 2006 Allan Brighton <abrighto@eso.org>
- Initial rpm build.

